===========
 Changelog
===========

2.7 (2017-12-26)
================

- Add breadcrumbs.

- Change `zope.interface.implements[Only]` and `zope.component.adapts` to
  class decorators.

- Also release as wheel.


2.6 (2017-04-08)
================

- Update to changes in test infrastructure in `icemac.addressbook >= 4.0`.

- Bring test coverage to 100 % including the tests themselves.


2.5 (2017-02-04)
================

- Update test infrastructure to `icemac.addressbook >= 3.0`.


Previous versions
=================

See ``OLD_CHANGES.rst`` inside the package.
